(function ($, document) {
  'use strict';

  var iconic_ww = {
    /**
     * On doc ready.
     */
    on_ready() {
      iconic_ww.ajax.init();
      iconic_ww.modal.init();
      iconic_ww.forms.init();
      iconic_ww.wishlist.init();
      iconic_ww.copy.init();
    },
    /**
     * Ajax methods.
     */
    ajax: {
      /**
       * Store request IDs to prevent duplicates.
       */
      request_ids: {},
      /**
       * Cached items.
       */
      cache() {
        iconic_ww.ajax.vars = {
          selectors: {
            buttons: '[data-iconic_ww_action]'
          }
        };
      },
      /**
       * Init ajax methods.
       */
      init() {
        iconic_ww.ajax.cache();
        iconic_ww.ajax.watch();
      },
      /**
       * Watch ajax related events.
       */
      watch() {
        $(document.body).on('click', iconic_ww.ajax.vars.selectors.buttons, iconic_ww.ajax.trigger_button_action);
      },
      /**
       * Trigger ajax button action.
       *
       * @param e
       */
      trigger_button_action(e) {
        e.preventDefault();
        let $button = $(this),
          action = $button.data('iconic_ww_action'),
          data = {
            action
          },
          args = $button.data('iconic_ww_args');
        if (typeof args !== 'undefined') {
          data = $.extend(data, args);
        }
        $(document.body).trigger('iconic_ww_ajax_event_started', [$button, data]);
        $(document.body).trigger('iconic_ww_ajax_event_started_' + action, [$button, data]);
        iconic_ww.ajax.post(data, function (response) {
          $(document.body).trigger('iconic_ww_ajax_event_complete', [$button, data, response]);
          $(document.body).trigger('iconic_ww_ajax_event_complete_' + action, [$button, data, response]);
        });
      },
      /**
       * Increment request ID.
       *
       * @param key
       * @return int
       */
      increment_request_id(key) {
        if (typeof iconic_ww.ajax.request_ids[key] === 'undefined') {
          iconic_ww.ajax.request_ids[key] = 0;
        } else {
          iconic_ww.ajax.request_ids[key]++;
        }
        return iconic_ww.ajax.request_ids[key];
      },
      /**
       * Post ajax request.
       *
       * @param data
       * @param callback
       */
      post(data, callback) {
        data.action = 'iconic_ww_' + data.action;
        data.request_id = iconic_ww.ajax.increment_request_id(data.action);
        data.nonce = iconic_ww_vars.nonce;
        $.post(iconic_ww_vars.ajax_url, data, function (response) {
          if (response.data.request_id !== iconic_ww.ajax.request_ids[data.action]) {
            console.log('Warning', 'Response ID did not match. Response ignored.');
            return;
          }
          if (!response.success) {
            response.data.message = typeof response.data.message !== 'undefined' ? response.data.message : 'There was an issue with the AJAX request.';
            console.log('Error', response.data.message);
          }
          if (typeof callback === 'function') {
            callback(response);
          }
        });
      }
    },
    /**
     * Ajax modal.
     */
    modal: {
      /**
       * Cached items.
       */
      cache() {
        iconic_ww.modal.vars = {
          selectors: {
            modal: '.iconic-ww-modal',
            wrap: '.iconic-ww-modal-wrap',
            container: '.iconic-ww-modal-container',
            overlay: '.iconic-ww-modal-overlay',
            close: '.iconic-ww-modal__close'
          }
        };
        iconic_ww.modal.els = {
          body: $(document.body)
        };
      },
      /**
       * Init.
       */
      init() {
        iconic_ww.modal.cache();
        iconic_ww.modal.watch();
      },
      /**
       * Watch events.
       */
      watch() {
        $(document.body).on('iconic_ww_ajax_event_started', function (e, $button, data) {
          if (data.action.indexOf('_modal') === -1) {
            return;
          }
          iconic_ww.modal.close();
        });
        $(document.body).on('iconic_ww_ajax_event_complete', function (e, $button, data, response) {
          if (data.action.indexOf('_modal') === -1) {
            return;
          }
          iconic_ww.modal.open(response.data.modal);
        });
        $(document.body).on('click', iconic_ww.modal.vars.selectors.close, function (e) {
          e.preventDefault();
          iconic_ww.modal.close();
        });
        $(document.body).on('click', iconic_ww.modal.vars.selectors.wrap, function (e) {
          if (!$(e.target).hasClass(iconic_ww.modal.vars.selectors.container.replace('.', ''))) {
            return true;
          }
          e.preventDefault();
          iconic_ww.modal.close();
        });
      },
      /**
       * Open modal.
       *
       * @param content
       */
      open(content) {
        $('html, body').css('overflow', 'hidden');
        iconic_ww.modal.els.body.append(content);
        iconic_ww.select.init();
      },
      /**
       * Close modal.
       */
      close() {
        $('html, body').css('overflow', '');
        $(iconic_ww.modal.vars.selectors.wrap).remove();
        $(iconic_ww.modal.vars.selectors.overlay).remove();
      }
    },
    /**
     * Select Fields.
     */
    select: {
      /**
       * Cached items.
       */
      cache() {
        iconic_ww.select.vars = {
          selectors: {
            select: '.iconic-ww-select',
            select_enhanced: '.iconic-ww-select--enhanced',
            select_container: '.iconic-ww-select-container'
          }
        };
      },
      /**
       * Init.
       */
      init() {
        iconic_ww.select.cache();
        iconic_ww.select.setup_select_fields();
      },
      /**
       * Setup select fields.
       */
      setup_select_fields() {
        $(iconic_ww.select.vars.selectors.select).on('change', function () {
          $(this).data('select2').$dropdown.addClass(iconic_ww.select.vars.selectors.select_container.replace('.', ''));
        });
        $(iconic_ww.select.vars.selectors.select).not(iconic_ww.select.vars.selectors.select_enhanced).selectWoo({
          width: '100%',
          height: '34px',
          minimumResultsForSearch: -1
        }).addClass(iconic_ww.select.vars.selectors.select_enhanced.replace('.', '')).change();
      }
    },
    /**
     * Forms.
     */
    forms: {
      /**
       * Cached items.
       */
      cache() {
        iconic_ww.forms.vars = {
          selectors: {
            ajax_forms: '[data-iconic-ww-ajax-form]',
            notice: '.iconic-ww-form__notice'
          },
          templates: {
            notice: '<div class="iconic-ww-form__notice iconic-ww-form__notice--%%notice_type%%">%%notice%%</div>'
          }
        };
      },
      /**
       * Init.
       */
      init() {
        iconic_ww.forms.cache();
        iconic_ww.forms.watch();
      },
      /**
       * Watch forms.
       */
      watch() {
        $(document.body).on('submit', iconic_ww.forms.vars.selectors.ajax_forms, function (e) {
          e.preventDefault();
          iconic_ww.forms.remove_notice();
          const $form = $(this),
            data = iconic_ww.forms.serialize($form),
            action = $form.data('iconic-ww-ajax-form');
          $(document.body).trigger('iconic_ww_' + action, {
            data,
            form: $form
          });
          iconic_ww.ajax.post({
            action,
            data
          }, function (response) {
            $(document.body).trigger('iconic_ww_' + action + '_complete', {
              response,
              form: $form
            });
          });
        });
      },
      /**
       * Serialize form data.
       *
       * @param  $form
       * @return {*}
       */
      serialize($form) {
        const data = $form.serializeArray();
        if (data.length <= 0) {
          return false;
        }
        const data_object = {};
        $.each(data, function (index, field) {
          data_object[field.name] = field.value;
        });
        return data_object;
      },
      /**
       * Remove notice.
       */
      remove_notice() {
        $(iconic_ww.forms.vars.selectors.notice).remove();
      },
      /**
       * Format notice.
       *
       * @param  message
       * @param  type
       * @return {string}
       */
      format_notice(message, type) {
        type = type === 'success' ? type + ' iconic-ww-form__notice--alone' : type;
        const notice = iconic_ww.forms.vars.templates.notice.replace('%%notice_type%%', type).replace('%%notice%%', message);
        return notice;
      },
      /**
       * Do form response.
       *
       * @param $form
       * @param response
       */
      do_form_response($form, response) {
        let notice = '';
        if (!response.success) {
          notice = iconic_ww.forms.format_notice(response.data.message, 'error');
          $form.prepend(notice);
          return;
        }
        const $modal_content = $form.closest(iconic_ww.wishlist.vars.selectors.modal_content);
        if ($modal_content.length <= 0) {
          return;
        }
        notice = iconic_ww.forms.format_notice(response.data.message, 'success');
        $modal_content.html(notice);
      }
    },
    /**
     * Wishlist.
     */
    wishlist: {
      /**
       * Cached items.
       */
      cache() {
        iconic_ww.wishlist.vars = {
          selectors: {
            modal_content: '.iconic-ww-modal__content',
            wishlists_table: '.iconic-ww-wishlists-table',
            wishlists_table_row: '.iconic-ww-wishlists-table__row',
            wishlists_table_title_link: '.iconic-ww-wishlists-table__title-link',
            wishlists_table_items_count: '.iconic-ww-wishlists-table__items_count',
            wishlists_table_created_date: '.iconic-ww-wishlists-table__created_date',
            wishlists_table_privacy: '.iconic-ww-wishlists-table__privacy',
            wishlists_table_action_edit: '.iconic-ww-wishlists-table__action-edit',
            wishlists_table_action_delete: '.iconic-ww-wishlists-table__action-delete',
            wishlist_item_row: '.iconic-ww-wishlist-items__item',
            select_wishlist_field: '#iconic_ww_choose_wishlist',
            create_wishlist_fields: '.iconic-ww-create-wishlist',
            wishlist_privacy_field: 'input[name="iconic_ww_wishlist_privacy"]',
            wishlist_user_fields: '.iconic-ww-form__user',
            variation_field: '.variation_id',
            add_to_wishlist_button: '.iconic-ww-button--add-to-wishlist'
          }
        };
      },
      /**
       * Init.
       */
      init() {
        iconic_ww.wishlist.cache();
        iconic_ww.wishlist.watch();
      },
      /**
       * Watch.
       */
      watch() {
        $(document.body).on('iconic_ww_add_to_wishlist_complete', iconic_ww.wishlist.added_to_wishlist);
        $(document.body).on('iconic_ww_edit_wishlist_complete', iconic_ww.wishlist.updated_wishlist);
        $(document.body).on('iconic_ww_delete_wishlist_complete', iconic_ww.wishlist.deleted_wishlist);
        $(document.body).on('iconic_ww_ajax_event_complete_remove_product', iconic_ww.wishlist.remove_product_complete);
        $(document.body).on('change', iconic_ww.wishlist.vars.selectors.select_wishlist_field, iconic_ww.wishlist.toggle_create_fields);
        $(document.body).on('change', iconic_ww.wishlist.vars.selectors.wishlist_privacy_field, iconic_ww.wishlist.toggle_user_fields);
        $(document.body).on('change', iconic_ww.wishlist.vars.selectors.variation_field, iconic_ww.wishlist.watch_variations);
      },
      /**
       * Watch for a variation selection.
       */
      watch_variations() {
        const $field = $(this),
          variation_id = $field.val(),
          $product = $field.closest('.product'),
          $wishlist_button = $product.find(iconic_ww.wishlist.vars.selectors.add_to_wishlist_button);
        if ($wishlist_button.length <= 0) {
          return;
        }
        const button_args = $wishlist_button.data('iconic_ww_args'),
          attributes = {},
          $form = $field.closest('form'),
          $attributes = $form.find('[name^="attribute_"]');
        if ($attributes.length > 0) {
          $attributes.each(function (index, attribute) {
            const $attribute = $(attribute),
              name = $attribute.attr('name');
            attributes[name] = $attribute.val();
          });
        }
        button_args.variation_id = variation_id === '' ? '' : parseInt(variation_id);
        button_args.attributes = attributes;
        $wishlist_button.data('iconic_ww_args', button_args);
      },
      /**
       * After add to wishlist.
       *
       * @param e
       * @param args
       */
      added_to_wishlist(e, args) {
        iconic_ww.forms.do_form_response(args.form, args.response);
      },
      /**
       * After create/update wishlist.
       *
       * @param e
       * @param args
       */
      updated_wishlist(e, args) {
        iconic_ww.forms.do_form_response(args.form, args.response);
        if (args.response.success === true) {
          iconic_ww.wishlist.update_wishlists_table(args.response.data.wishlist);
        }
      },
      /**
       * After deleting wishlist.
       *
       * @param e
       * @param args
       */
      deleted_wishlist(e, args) {
        iconic_ww.forms.do_form_response(args.form, args.response);
        if (!args.response.data.has_wishlists) {
          location.reload();
          return;
        }
        iconic_ww.wishlist.remove_wishlists_table_row(args.response.data.form_data.wishlist_id);
      },
      /**
       * Update wishlists table if it exists.
       *
       * @param wishlist
       */
      update_wishlists_table(wishlist) {
        const $table = $(iconic_ww.wishlist.vars.selectors.wishlists_table);
        if ($table.length <= 0) {
          location.reload();
          return;
        }
        const $row = $table.find('[data-iconic_ww_wishlist_id="' + wishlist.id + '"]');
        if ($row.length <= 0) {
          // Insert row.
          const $first_row = $(iconic_ww.wishlist.vars.selectors.wishlists_table_row + ':first');
          if ($first_row.length <= 0) {
            return;
          }
          const $first_row_clone = $first_row.clone();
          iconic_ww.wishlist.update_wishlist_row($first_row_clone, wishlist);
          $first_row.before($first_row_clone);
        } else {
          // update row.
          iconic_ww.wishlist.update_wishlist_row($row, wishlist);
        }
      },
      /**
       * Update wishlist row data.
       *
       * @param $row
       * @param wishlist
       */
      update_wishlist_row($row, wishlist) {
        let $title_link = $row.find(iconic_ww.wishlist.vars.selectors.wishlists_table_title_link),
          $items_count = $row.find(iconic_ww.wishlist.vars.selectors.wishlists_table_items_count),
          $created = $row.find(iconic_ww.wishlist.vars.selectors.wishlists_table_created_date),
          $privacy = $row.find(iconic_ww.wishlist.vars.selectors.wishlists_table_privacy),
          $edit = $row.find(iconic_ww.wishlist.vars.selectors.wishlists_table_action_edit),
          $delete = $row.find(iconic_ww.wishlist.vars.selectors.wishlists_table_action_delete),
          json = JSON.stringify({
            wishlist_id: wishlist.id
          });
        $title_link.attr('title', wishlist.name).attr('href', wishlist.url).html('<strong>' + wishlist.name + '</strong>');
        if ($delete.length <= 0) {
          $delete = $('<a>').attr('data-iconic_ww_action', 'get_delete_wishlist_modal').attr('href', '#').attr('class', 'iconic-ww-wishlists-table__action-delete').html(iconic_ww_vars.i18n.delete);
          $edit.after($delete);
        }
        $delete.attr('data-iconic_ww_args', json);
        $edit.attr('data-iconic_ww_args', json);
        $row.attr('data-iconic_ww_wishlist_id', wishlist.id);
        $items_count.html(wishlist.items_count_formatted);
        $created.html(wishlist.created_date);
        $privacy.html(wishlist.privacy);
      },
      /**
       * Remove wishlist row.
       *
       * @param wishlist_id
       */
      remove_wishlists_table_row(wishlist_id) {
        const $table = $(iconic_ww.wishlist.vars.selectors.wishlists_table);
        if ($table.length <= 0) {
          return;
        }
        $table.find('[data-iconic_ww_wishlist_id="' + wishlist_id + '"]').remove();
      },
      /**
       * Remove product from wishlist complete.
       * @param e
       * @param $button
       * @param data
       * @param response
       */
      remove_product_complete(e, $button, data, response) {
        if (!response.success) {
          return;
        }
        const $rows = $button.closest('table').find(iconic_ww.wishlist.vars.selectors.wishlist_item_row);
        if ($rows.length <= 1) {
          location.reload();
          return;
        }
        const $row = $button.closest('tr');
        $row.remove();
      },
      /**
       * Toggle create fields.
       */
      toggle_create_fields() {
        const $select = $(this),
          value = $select.val(),
          $form = $select.closest('form'),
          $create_fields = $form.find(iconic_ww.wishlist.vars.selectors.create_wishlist_fields);
        if (value === 'iconic_ww_new') {
          $create_fields.show();
          return;
        }
        $create_fields.hide();
      },
      /**
       * Toggle user fields.
       */
      toggle_user_fields() {
        const $input = $(this),
          value = $input.val(),
          $form = $input.closest('form'),
          $user_fields = $form.find(iconic_ww.wishlist.vars.selectors.wishlist_user_fields);
        if (value === 'publish') {
          $user_fields.show();
          return;
        }
        $user_fields.hide();
      }
    },
    /**
     * Copy links.
     */
    copy: {
      /**
       * Cached items.
       */
      cache() {
        iconic_ww.copy.vars = {
          selectors: {
            copy: '.iconic-ww-copy',
            copy_field: '.iconic-ww-copy__field',
            copy_button: '.iconic-ww-copy__button',
            copy_button_disabled: '.iconic-ww-copy__button-disabled'
          }
        };
      },
      /**
       * Init.
       */
      init() {
        iconic_ww.copy.cache();
        iconic_ww.copy.watch();
      },
      /**
       * Watch.
       */
      watch() {
        $(document.body).on('click', iconic_ww.copy.vars.selectors.copy_button, function () {
          const $button = $(this);
          if ($button.hasClass(iconic_ww.copy.vars.selectors.copy_button_disabled)) {
            return;
          }
          $button.addClass(iconic_ww.copy.vars.selectors.copy_button_disabled);
          const $wrapper = $button.closest(iconic_ww.copy.vars.selectors.copy),
            $field = $wrapper.find(iconic_ww.copy.vars.selectors.copy_field),
            value = $field.val();

          /* Select the text field */
          $field.select();

          /* Copy the text inside the text field */
          document.execCommand('copy');

          /* Alert the copied text */
          $field.val(iconic_ww_vars.i18n.copied).blur().attr('disabled', true);
          setTimeout(function () {
            $button.removeClass(iconic_ww.copy.vars.selectors.copy_button_disabled);
            $field.val(value).attr('disabled', false);
          }, 2000);
        });
      }
    }
  };
  $(document).ready(iconic_ww.on_ready());
})(jQuery, document);