<?php
/**
 * Settings admin
 *
 * @package iconic-woo-wishlists
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

add_filter( 'wpsf_register_settings_iconic_ww', 'iconic_ww_settings' );

/**
 * WooCommerce Wishlist Settings
 *
 * @param array $settings The settings.
 *
 * @return array
 */
function iconic_ww_settings( $settings ) {
	// Tabs.

	$settings['tabs'][] = array(
		'id'    => 'general',
		'title' => __( 'General', 'iconic-ww' ),
	);

	$settings['tabs'][] = array(
		'id'    => 'buttons',
		'title' => __( 'Buttons', 'iconic-ww' ),
	);

	// Sections.

	$settings['sections'][] = array(
		'tab_id'              => 'general',
		'section_id'          => 'page',
		'section_title'       => __( 'Page Settings', 'iconic-ww' ),
		'section_description' => '',
		'section_order'       => 0,
		'fields'              => array(
			array(
				'id'       => 'id',
				'title'    => __( 'Wishlist Page', 'iconic-ww' ),
				'subtitle' => __( 'Choose a page that holds the [iconic_ww_wishlists] shortcode. This page will also be given the endpoints of /view and /find.', 'iconic-ww' ),
				'type'     => 'select',
				'default'  => '',
				'choices'  => Iconic_WW_Helpers::get_page_options(),
			),
		),
	);

	$settings['sections'][] = array(
		'tab_id'              => 'buttons',
		'section_id'          => 'positions',
		'section_title'       => __( 'Positions', 'iconic-ww' ),
		'section_description' => '',
		'section_order'       => 0,
		'fields'              => array(
			array(
				'id'       => 'add_to_wishlist',
				'title'    => __( 'Product Page Button Position', 'iconic-ww' ),
				'subtitle' => sprintf( '%s <br><br> %s', __( 'Where should the "Add to Wishlist" button appear on the single product page?', 'iconic-ww' ), __( 'If you choose "None" you will need to add the [iconic_ww_add_to_wishlist] shortcode to your product page manually.', 'iconic-ww' ) ),
				'type'     => 'select',
				'default'  => 'after_add_to_cart',
				'choices'  => array(
					''                   => __( 'None', 'iconic-ww' ),
					'after_add_to_cart'  => __( 'After "Add to Cart" Button', 'iconic-ww' ),
					'after_title'        => __( 'After Product Title', 'iconic-ww' ),
					'before_description' => __( 'Before Description', 'iconic-ww' ),
					'after_description'  => __( 'After Description', 'iconic-ww' ),
				),
			),
			array(
				'id'       => 'add_to_wishlist_shop',
				'title'    => __( 'Shop Page Button Position', 'iconic-ww' ),
				'subtitle' => __( 'Where should the "Add to Wishlist" button appear on the shop/archive pages?' ),
				'type'     => 'select',
				'default'  => 'after_add_to_cart_shop',
				'choices'  => array(
					''                       => __( 'None', 'iconic-ww' ),
					'before_link_shop'       => __( 'Before Link', 'iconic-ww' ),
					'after_thumbnail_shop'   => __( 'After Thumbnail', 'iconic-ww' ),
					'after_title_shop'       => __( 'After Title', 'iconic-ww' ),
					'after_add_to_cart_shop' => __( 'After "Add to Cart" Button', 'iconic-ww' ),
				),
			),
		),
	);

	$settings['sections'][] = array(
		'tab_id'              => 'buttons',
		'section_id'          => 'style',
		'section_title'       => __( 'Style', 'iconic-ww' ),
		'section_description' => '',
		'section_order'       => 0,
		'fields'              => array(
			array(
				'id'       => 'add_to_wishlist_type',
				'title'    => __( '"Add to Wishlist" Type', 'iconic-ww' ),
				'subtitle' => __( 'Should the "Add to Wishlist" button be displayed as a standard link, or a styled button?', 'iconic-ww' ),
				'type'     => 'select',
				'default'  => 'button',
				'choices'  => array(
					'link'   => __( 'Link', 'iconic-ww' ),
					'button' => __( 'Button', 'iconic-ww' ),
				),
			),
			array(
				'id'       => 'add_to_wishlist_icon',
				'title'    => __( '"Add to Wishlist" Icon', 'iconic-ww' ),
				'subtitle' => '',
				'type'     => 'select',
				'default'  => 'heart-solid',
				'choices'  => array(
					''                  => __( 'None', 'iconic-ww' ),
					'heart-solid'       => __( 'Heart', 'iconic-ww' ),
					'star-solid'        => __( 'Star', 'iconic-ww' ),
					'plus-solid'        => __( 'Plus', 'iconic-ww' ),
					'plus-circle-solid' => __( 'Plus Circle', 'iconic-ww' ),
				),
			),
			array(
				'id'       => 'create_wishlist_icon',
				'title'    => __( '"Create Wishlist" Icon', 'iconic-ww' ),
				'subtitle' => '',
				'type'     => 'select',
				'default'  => 'plus-solid',
				'choices'  => array(
					''                  => __( 'None', 'iconic-ww' ),
					'plus-solid'        => __( 'Plus', 'iconic-ww' ),
					'plus-circle-solid' => __( 'Plus Circle', 'iconic-ww' ),
				),
			),
			array(
				'id'       => 'search_icon',
				'title'    => __( 'Search Icon', 'iconic-ww' ),
				'subtitle' => '',
				'type'     => 'select',
				'default'  => 'search-solid',
				'choices'  => array(
					''             => __( 'None', 'iconic-ww' ),
					'search-solid' => __( 'Magnifying Glass', 'iconic-ww' ),
				),
			),
		),
	);

	return $settings;
}
