<?php
/**
 * Assets class
 *
 * @package iconic-woo-wishlists
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Iconic_WW_Assets.
 *
 * @class    Iconic_WW_Assets
 * @version  1.0.0
 */
class Iconic_WW_Assets {
	/**
	 * Run.
	 */
	public static function run() {
		add_action( 'wp_enqueue_scripts', array( __CLASS__, 'frontend_assets' ) );
	}

	/**
	 * Frontend assets.
	 */
	public static function frontend_assets() {
		if ( is_admin() ) {
			return;
		}

		self::register_scripts();
		self::frontend_scripts();
		self::register_styles();
		self::frontend_styles();
	}

	/**
	 * Register frontend scripts.
	 */
	private static function register_scripts() {
		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		$register_scripts = array(
			'iconic-ww' => array(
				'src'      => ICONIC_WW_URL . 'assets/frontend/js/main' . $suffix . '.js',
				'deps'     => array( 'jquery', 'selectWoo' ),
				'version'  => ICONIC_WW_VERSION,
				'localize' => array(
					'nonce'    => wp_create_nonce( 'iconic-ww' ),
					'ajax_url' => admin_url( 'admin-ajax.php' ),
					'i18n'     => array(
						'delete' => __( 'Delete', 'iconic-ww' ),
						'copied' => __( 'Copied to clipboard!', 'iconic-ww' ),
					),
				),
			),
		);

		foreach ( $register_scripts as $name => $props ) {
			wp_register_script( $name, $props['src'], $props['deps'], $props['version'], true );

			if ( ! empty( $props['localize'] ) ) {
				$js_name = sprintf( '%s_vars', str_replace( '-', '_', $name ) );
				wp_localize_script( $name, $js_name, $props['localize'] );
			}
		}
	}

	/**
	 * Load all frontend scripts.
	 */
	public static function frontend_scripts() {
		$enqueue = array(
			'jquery',
			'iconic-ww',
		);

		foreach ( $enqueue as $handle ) {
			wp_enqueue_script( $handle );
		}
	}

	/**
	 * Register frontend styles.
	 */
	private static function register_styles() {
		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		wp_enqueue_script( 'select2' );

		$register_styles = array(
			'iconic-ww' => array(
				'src'     => ICONIC_WW_URL . 'assets/frontend/css/main' . $suffix . '.css',
				'deps'    => array( 'select2' ),
				'version' => ICONIC_WW_VERSION,
			),
		);

		foreach ( $register_styles as $name => $props ) {
			wp_register_style( $name, $props['src'], $props['deps'], $props['version'] );
		}
	}

	/**
	 * Load all frontend styles.
	 */
	public static function frontend_styles() {
		$enqueue = array(
			'iconic-ww',
		);

		foreach ( $enqueue as $handle ) {
			wp_enqueue_style( $handle );
		}
	}
}
