<?php
/**
 * Settings class
 *
 * @package iconic-woo-wishlists
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Iconic_WW_Settings.
 *
 * @class    Iconic_WW_Settings
 * @version  1.0.0
 */
class Iconic_WW_Settings {
	/**
	 * Run.
	 */
	public static function run() {
		add_action( 'update_option_iconic_ww_settings', array( __CLASS__, 'on_save' ), 10, 2 );
	}

	/**
	 * Run actions on save settings.
	 *
	 * @param mixed $old The old value.
	 * @param mixed $new The new value.
	 */
	public static function on_save( $old, $new ) {
		if ( $old['general_page_id'] !== $new['general_page_id'] ) {
			flush_rewrite_rules();
		}
	}

	/**
	 * Get the icon name.
	 *
	 * @param string $icon The icon.
	 *
	 * @return mixed
	 */
	public static function get_icon_name( $icon ) {
		return Iconic_WW_Core_Settings::get_setting( 'buttons_style_' . $icon . '_icon' );
	}

	/**
	 * Output icon.
	 *
	 * @param string      $icon The icon name.
	 * @param bool|string $size The size.
	 */
	public static function output_icon( $icon, $size = false ) {
		$name = self::get_icon_name( $icon );
		Iconic_WW_Helpers::output_svg( $name, $size );
	}
}
