<?php
/**
 * Iconic_WW_Shortcodes class
 *
 * @package iconic-woo-wishlists
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Iconic_WW_Shortcodes.
 *
 * @class    Iconic_WW_Shortcodes.
 * @version  1.0.0
 */
class Iconic_WW_Shortcodes {
	/**
	 * Run.
	 */
	public static function run() {
		if ( is_admin() && ! wp_doing_ajax() ) {
			return;
		}

		add_shortcode( 'iconic_ww_wishlists', array( __CLASS__, 'wishlists' ) );
		add_shortcode( 'iconic_ww_add_to_wishlist', array( __CLASS__, 'add_to_wishlist' ) );
	}

	/**
	 * Main wishlists shortcode.
	 */
	public static function wishlists() {
		$endpoint = Iconic_WW_Endpoints::$current_endpoint;

		ob_start();

		if ( ! $endpoint ) {
			?>
			<p class="woocommerce-error"><?php esc_html_e( 'Please select this page for wishlists in the settings.', 'iconic-ww' ); ?></p>
			<?php
			return ob_get_clean();
		}

		/**
		 * Hook: iconic_ww_before_content.
		 *
		 * @see Iconic_WW_Endpoints
		 */
		do_action( 'iconic_ww_before_content' );

		/**
		 * Hook: iconic_ww_content_{$endpoint}.
		 *
		 * @see Iconic_WW_Endpoints
		 */
		do_action( 'iconic_ww_content_' . $endpoint );

		/**
		 * Hook: iconic_ww_after_content.
		 *
		 * @see Iconic_WW_Endpoints
		 */
		do_action( 'iconic_ww_after_content' );

		return ob_get_clean();
	}

	/**
	 * Add to wishlist button shortcode.
	 *
	 * @param array $args Array of attributes.
	 *
	 * @return string
	 */
	public static function add_to_wishlist( $args = array() ) {
		global $product;

		$original_product = $product;

		if ( isset( $args['product_id'] ) ) {
			$post_object = get_post( $args['product_id'] );

			if ( ! $post_object || $post_object->post_password ) {
				return;
			}

			$product = wc_get_product( $args['product_id'] );
		}

		if ( ! $product ) {
			$product = $original_product;
			return '';
		}

		ob_start();

		Iconic_WW_Helpers::include_template( 'components/add-to-wishlist-button' );

		return ob_get_clean();
	}
}
