<?php
/**
 * Wishlist items loop template
 *
 * @package iconic-woo-wishlists
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

?>

<?php if ( empty( $items ) ) { ?>
	<p class="woocommerce-info">
		<?php esc_html_e( 'This wishlist is currently empty.', 'iconic-ww' ); ?>
		<a
			class="button wc-backward"
			href="
			<?php
			echo esc_url(
				/**
				 * Filter "Return To Shop" redirect
				 *
				 * @hook woocommerce_return_to_shop_redirect
				 * @param string $shop_page_permalink The shop page permalink.
				 */
				apply_filters( 'woocommerce_return_to_shop_redirect', wc_get_page_permalink( 'shop' ) )
			);
			?>
			">
			<?php esc_html_e( 'Return to shop', 'woocommerce' ); ?>
		</a>
	</p>
	<?php
		return;
}
?>

<table class="iconic-ww-table iconic-ww-wishlist-items" cellspacing="0">
	<thead>
	<tr>
		<?php if ( $user->is_author( $wishlist ) ) { ?>
			<th class="iconic-ww-wishlist-items__item-column iconic-ww-wishlist-items__item-column--delete-item">&nbsp;</th>
		<?php } ?>
		<th class="iconic-ww-wishlist-items__item-column iconic-ww-wishlist-items__item-column--thumbnail">&nbsp;</th>
		<th><?php esc_html_e( 'Product', 'iconic-ww' ); ?></th>
		<th><?php esc_html_e( 'Price', 'iconic-ww' ); ?></th>
		<th>&nbsp;</th>
	</tr>
	</thead>
	<tbody>
	<?php
	foreach ( $items as $item ) {
		global $product;

		$product           = $item['product'];
		$parent_product_id = $product->get_parent_id();
		$parent_product    = $product->get_parent_id() ? wc_get_product( $parent_product_id ) : $product;
		?>

		<tr class="iconic-ww-wishlist-items__item">
			<?php
			if ( $user->is_author( $wishlist ) ) {
				$json_args = Iconic_WW_Helpers::get_json_args(
					array(
						'wishlist_id' => $wishlist->get( 'ID' ),
						'product_id'  => $product->get_id(),
					)
				);
				?>
				<td class="iconic-ww-wishlist-items__item-column iconic-ww-wishlist-items__item-column--delete-item">
					<a
						href="javascript: void( 0 );"
						class="iconic-ww-button iconic-ww-button--delete"
						aria-label="<?php esc_attr_e( 'Remove this item', 'iconic-ww' ); ?>"
						data-iconic_ww_action="remove_product"
						data-iconic_ww_args="<?php echo esc_attr( $json_args ); ?>"
					>
						<?php Iconic_WW_Helpers::output_svg( 'times-circle-solid', 'large' ); ?>
					</a>
				</td>
			<?php } ?>
			<td class="iconic-ww-wishlist-items__item-column iconic-ww-wishlist-items__item-column--thumbnail">
				<a href="<?php echo esc_url( $item['url'] ); ?>" title="<?php echo esc_attr( $product->get_name() ); ?>">
					<?php echo wp_kses_post( $product->get_image() ); ?>
				</a>
			</td>
			<td class="iconic-ww-wishlist-items__item-column iconic-ww-wishlist-items__item-column--product">
				<div class="iconic-ww-wishlist-items__item-name">
					<a href="<?php echo esc_url( $item['url'] ); ?>" title="<?php echo esc_attr( $product->get_name() ); ?>">
						<?php echo esc_html( $product->get_name() ); ?>
					</a>
				</div>
				<?php echo wp_kses_post( wc_get_rating_html( $parent_product->get_average_rating() ) ); ?>
				<?php
				echo wp_kses_post(
					wc_get_formatted_cart_item_data(
						array(
							'data'      => $product,
							'variation' => $item['attributes'],
							'iconic-ww' => true,
						)
					)
				);
				?>
				<?php echo wp_kses_post( wc_get_stock_html( $product ) ); ?>
			</td>
			<td class="iconic-ww-wishlist-items__item-column iconic-ww-wishlist-items__item-column--price">
				<?php echo wp_kses_post( $product->get_price_html() ); ?>
			</td>
			<td class="iconic-ww-wishlist-items__item-column iconic-ww-wishlist-items__item-column--add-to-cart">
				<p class="iconic-ww-wishlist-items__added-date">
					<?php
						// translators: %s - 'Added'; %s item added.
						echo esc_html( sprintf( '%s: %s', __( 'Added', 'iconic-ww' ), $item['added'] ) );
					?>
				</p>
				<?php
				woocommerce_template_loop_add_to_cart(
					array(
						'iconic-ww'            => true,
						'iconic-ww-attributes' => $item['attributes'],
					)
				);
				?>
			</td>
		</tr>

	<?php } ?>
	</tbody>
</table>
