<?php
/**
 * Wishlist loop template
 *
 * @package iconic-woo-wishlists
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

?>

<?php
if ( empty( $wishlists ) ) {
	echo wp_kses_post( Iconic_WW_Wishlists::get_no_wishlists_message() );
	return;
}
?>

<?php if ( Iconic_WW_Endpoints::is( 'base' ) ) { ?>
	<button class="iconic-ww-button iconic-ww-button--create-wishlist button" data-iconic_ww_action="get_create_wishlist_modal">
		<?php Iconic_WW_Settings::output_icon( 'create_wishlist' ); ?>
		<?php
			// translators: %s wishlist label.
			echo esc_html( sprintf( __( 'Create %s', 'iconic-ww' ), Iconic_WW_Wishlists::get_wishlists_label( 'singular' ) ) );
		?>
	</button>
<?php } ?>

<table class="iconic-ww-table iconic-ww-wishlists-table" cellspacing="0">
	<thead>
	<tr>
		<th><?php esc_html_e( 'List Name', 'iconic-ww' ); ?></th>
		<th><?php esc_html_e( 'Items', 'iconic-ww' ); ?></th>
		<th><?php esc_html_e( 'Date Created', 'iconic-ww' ); ?></th>
		<?php if ( Iconic_WW_Endpoints::is( 'base' ) ) { ?>
			<th><?php esc_html_e( 'Privacy', 'iconic-ww' ); ?></th>
		<?php } ?>
		<?php if ( Iconic_WW_Endpoints::is( 'find' ) ) { ?>
			<th><?php esc_html_e( 'User', 'iconic-ww' ); ?></th>
		<?php } ?>
	</tr>
	</thead>
	<tbody>
	<?php foreach ( $wishlists as $wishlist ) { ?>
		<tr class="iconic-ww-wishlists-table__row" data-iconic_ww_wishlist_id="<?php echo esc_attr( $wishlist->get( 'ID' ) ); ?>">
			<td class="iconic-ww-wishlists-table__title">
				<a href="<?php echo esc_attr( $wishlist->get( 'url' ) ); ?>" title="<?php echo esc_attr( $wishlist->get( 'post_title' ) ); ?>" class="iconic-ww-wishlists-table__title-link">
					<strong><?php echo esc_html( $wishlist->get( 'post_title' ) ); ?></strong>
				</a>
				<?php
				if ( ! empty( $user ) && $user->get( 'ID', array(), 'int' ) === $wishlist->get( 'post_author', array(), 'int' ) ) {
					$json_args = Iconic_WW_Helpers::get_json_args(
						array(
							'wishlist_id' => $wishlist->get( 'ID' ),
						)
					);
					?>
					<div class="iconic-ww-wishlists-table__actions">
						<ul class="iconic-ww-wishlist-meta">
							<li class="iconic-ww-wishlist-meta__item">
								<a href="javascript: void( 0 );" class="iconic-ww-wishlists-table__action-edit" data-iconic_ww_action="get_edit_wishlist_modal" data-iconic_ww_args="<?php echo esc_attr( $json_args ); ?>">
									<?php esc_html_e( 'Edit', 'iconic-ww' ); ?>
								</a>
							</li>
							<li class="iconic-ww-wishlist-meta__item">
								<a href="javascript: void( 0 );" class="iconic-ww-wishlists-table__action-delete" data-iconic_ww_action="get_delete_wishlist_modal" data-iconic_ww_args="<?php echo esc_attr( $json_args ); ?>">
									<?php esc_html_e( 'Delete', 'iconic-ww' ); ?>
								</a>
							</li>
						</ul>
					</div>
				<?php } ?>
			</td>
			<td class="iconic-ww-wishlists-table__items_count">
				<?php echo esc_html( $wishlist->get( 'items_count_formatted' ) ); ?>
			</td>
			<td class="iconic-ww-wishlists-table__created_date">
				<?php echo esc_html( $wishlist->get( 'created_date' ) ); ?>
			</td>
			<?php if ( Iconic_WW_Endpoints::is( 'base' ) ) { ?>
				<td class="iconic-ww-wishlists-table__privacy">
					<?php echo wp_kses_post( $wishlist->get( 'privacy' ) ); ?>
				</td>
			<?php } ?>
			<?php if ( Iconic_WW_Endpoints::is( 'find' ) ) { ?>
				<td class="iconic-ww-wishlists-table__user">
					<?php echo wp_kses_post( $wishlist->get( 'user' ) ); ?>
				</td>
			<?php } ?>
		</tr>
	<?php } ?>
	</tbody>
</table>

<div class="iconic-ww-nav">
	<?php previous_posts_link( Iconic_WW_Helpers::output_svg( 'arrow-left-solid', '', false ) . __( 'Previous', 'iconic-ww' ) ); ?>
	<?php next_posts_link( __( 'Next', 'iconic-ww' ) . Iconic_WW_Helpers::output_svg( 'arrow-right-solid', '', false ), $GLOBALS['iconic_ww_wishlists_query']->max_num_pages ); ?>
</div>
