<?php
/**
 * Add wishlist modal template
 *
 * @package iconic-woo-wishlists
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( empty( $product ) ) {
	return;
}

$user      = new Iconic_WW_User();
$wishlists = $user->get(
	'wishlists',
	array(
		'limit' => - 1,
	)
);
?>

	<h2 class="iconic-ww-modal__title">
		<?php
			// translators: %s wishlist label.
			echo esc_html( sprintf( __( 'Add to %s', 'iconic-ww' ), Iconic_WW_Wishlists::get_wishlists_label( 'singular' ) ) );
		?>
	</h2>

<?php if ( 0 === $user->get( 'ID' ) ) { ?>
	<div class="iconic-ww-modal__scroll">
		<p>
			<?php
				// translators: %s wishlist label.
				echo esc_html( sprintf( __( 'Please log in to add an item to your %s.', 'iconic-ww' ), Iconic_WW_Wishlists::get_wishlists_label( 'singular' ) ) );
			?>
		</p>
	</div>
	<div class="iconic-ww-modal__footer">
		<a href="<?php echo esc_url( wc_get_page_permalink( 'myaccount' ) ); ?>" class="button iconic-ww-button"><?php esc_html_e( 'My Account', 'iconic-ww' ); ?></a>
	</div>
<?php } else { ?>
	<form action="" class="iconic-ww-form iconic-ww-form--styled iconic-ww-form--add-to-wishlist" data-iconic-ww-ajax-form="add_to_wishlist">
		<div class="iconic-ww-modal__scroll">
			<div class="iconic-ww-form__row">
				<label for="iconic_ww_choose_wishlist" class="iconic-ww-form__label">
					<?php
						// translators: %s wishlist label.
						echo esc_html( sprintf( __( 'Choose %s', 'iconic-ww' ), Iconic_WW_Wishlists::get_wishlists_label( 'singular' ) ) );
					?>
					:
				</label>
				<select class="iconic-ww-form__field iconic-ww-form__field--select iconic-ww-select" name="iconic_ww_choose_wishlist" id="iconic_ww_choose_wishlist">
					<?php if ( ! empty( $wishlists ) ) { ?>
						<?php foreach ( $wishlists as $wishlist ) { ?>
							<option value="<?php echo esc_attr( $wishlist->get( 'ID' ) ); ?>"><?php echo esc_html( $wishlist->get( 'post_title' ) ); ?></option>
						<?php } ?>
					<?php } ?>
					<option value="iconic_ww_new"><?php esc_html_e( 'Create New', 'iconic-ww' ); ?></option>
				</select>
			</div>

			<div class="iconic-ww-create-wishlist iconic-ww-form__hidden">
				<?php Iconic_WW_Helpers::include_template( 'components/form-row-name' ); ?>
				<?php Iconic_WW_Helpers::include_template( 'components/form-row-status' ); ?>
			</div>

			<input type="hidden" name="iconic_ww_product_id" value="<?php echo esc_attr( $product_id ); ?>">
			<input type="hidden" name="iconic_ww_variation_id" value="<?php echo esc_attr( $variation_id ); ?>">
			<input type="hidden" name="iconic_ww_attributes" value="<?php echo esc_attr( wp_json_encode( $attributes ) ); ?>">
		</div>

		<div class="iconic-ww-modal__footer">
			<button class="iconic-ww-button button">
				<?php Iconic_WW_Settings::output_icon( 'add_to_wishlist' ); ?>
				<?php
					// translators: %s wishlist label.
					echo esc_html( sprintf( __( 'Add to %s', 'iconic-ww' ), Iconic_WW_Wishlists::get_wishlists_label( 'singular' ) ) );
				?>
			</button>
		</div>
	</form>
<?php } ?>
