<?php
/**
 * Share wishlist modal template
 *
 * @package iconic-woo-wishlists
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( empty( $wishlist_id ) ) {
	return;
}

$wishlist = new Iconic_WW_Wishlist( $wishlist_id );

if ( ! $wishlist ) {
	return;
}

$links = $wishlist->get( 'share_links' );

$allowed_svg_elements_and_attributes = array(
	'svg'  => array(
		'xmlns'       => array(),
		'fill'        => array(),
		'viewbox'     => array(),
		'role'        => array(),
		'aria-hidden' => array(),
		'focusable'   => array(),
		'data-prefix' => array(),
		'data-icon'   => array(),
		'class'       => array(),
	),
	'path' => array(
		'd'    => array(),
		'fill' => array(),
	),
	'span' => array(
		'class' => array(),
	),
);
?>

<h2 class="iconic-ww-modal__title">
	<?php
		// translators: %s wishlist label.
		echo esc_html( sprintf( __( 'Share %s', 'iconic-ww' ), Iconic_WW_Wishlists::get_wishlists_label( 'singular' ) ) );
	?>
</h2>

<div class="iconic-ww-modal__scroll iconic-ww-modal__scroll--body">
	<div class="iconic-ww-copy">
		<input class="iconic-ww-copy__field iconic-ww-input-field" type="text" value="<?php echo esc_attr( $wishlist->get( 'url' ) ); ?>">
		<a 
			class="iconic-ww-copy__button"
			href="javascript: void( 0 );"
			<?php // translators: %s wishlist label. ?>
			title="<?php echo esc_attr( sprintf( __( 'Copy %s URL', 'iconic-ww' ), Iconic_WW_Wishlists::get_wishlists_label( 'singular' ) ) ); ?>"
		>
			<?php Iconic_WW_Helpers::output_svg( 'copy-solid' ); ?>
		</a>
	</div>

	<?php if ( ! empty( $links ) ) { ?>
		<ul class="iconic-ww-share-links">
			<?php foreach ( $links as $share_type => $share_link ) { ?>
				<li class="iconic-ww-share-links__item">
					<a href="<?php echo esc_attr( $share_link['link'] ); ?>" class="iconic-ww-button iconic-ww-button--social iconic-ww-button--<?php echo esc_attr( $share_type ); ?>" 
										<?php
										if ( 'email' !== $share_type ) {
											echo 'target="_blank"'; }
										?>
					>
						<?php echo wp_kses( $share_link['icon'], $allowed_svg_elements_and_attributes ); ?>
						<?php echo esc_html( $share_link['title'] ); ?>
					</a>
				</li>
			<?php } ?>
		</ul>
	<?php } ?>
</div>
